Module node

Module node 

Structs

OSMNode
OSMNode contains all information that we might care about in a node. Currently, it contains a node ID (as defined in Overpass API) a latitude and a longitude.

Functions

filter_unconnected_nodes
Given a set of nodes and ways, this function tries to parse all OSMNodes that lie on one of the ways provided.
get_nodes_from_ways
Given a json type structure and a Vec<OSMWay>, this function tries to parse all OSMNodes out of that json if and only if the node lies on one of the ways provided.
get_osm_nodes
Given a json type structure, this function tries to parse all OSMNodes out of that json.