get_nodes_from_ways

Function get_nodes_from_ways 

pub fn get_nodes_from_ways(
    elements: &Vec<Element>,
    ways: &Vec<OSMWay>,
) -> Result<Vec<OSMNode>, Box<dyn Error>>
Given a json type structure and a Vec<OSMWay>, this function tries to parse all OSMNodes out of that json if and only if the node lies on one of the ways provided.