OSMNode contains all information that we might care about in a node. Currently, it contains a
node ID (as defined in Overpass API) a latitude and a longitude.
Given a json type structure and a Vec<OSMWay>, this function tries to
parse all OSMNodes out of that json if and only if the node lies on one of the ways provided.